@@ -225,6 +225,7 @@ DualSimulations <- function(rhoEst,
 ##' @slot nObs number of patients overall
 ##' @slot nAboveTarget number of patients treated above target tox interval
 ##' @slot doseGrid the dose grid that has been used
+##' @slot placebo set to TRUE (default is FALSE) for a design with placebo
 ##'
 ##' @export
 ##' @keywords classes
@@ -233,16 +234,17 @@ DualSimulations <- function(rhoEst,
              representation(target="numeric",
                             targetDoseInterval="numeric",
                             nsim="integer",
-                            propDLTs="numeric",
+                            propDLTs="ANY",
                             meanToxRisk="numeric",
                             doseSelected="numeric",
                             toxAtDosesSelected="numeric",
                             propAtTarget="numeric",
                             doseMostSelected="numeric",
                             obsToxRateAtDoseMostSelected="numeric",
-                            nObs="integer",
+                            nObs="ANY",
                             nAboveTarget="integer",
-                            doseGrid="numeric"))
+                            doseGrid="numeric",
+                            placebo="logical"))
 
 
 ##' Class for the summary of model-based simulations output
@@ -302,6 +304,20 @@ DualSimulations <- function(rhoEst,
 ##' @slot fit list of the final values. If samples are involved, these are the final fitted values.
 ##' If no samples are involved, these are included the final modal estimates of the model parameters
 ##' and the posterior estimates of the probabilities of the occurrence of a DLE.
+##' @slot FinalTDtargetDuringTrialEstimates the vector of all final estimates (the last estimate of) the TDtargetDuringTrial at the end 
+##' of each simultaions/when each trial stops
+##' @slot FinalTDtargetEndOfTrialEstimates vector of all final estimates or the last estimate of the TDtargetEndOfTrial when each trial 
+##' stops
+##' @slot FinalTDtargetDuringTrialAtDoseGrid vector of the dose levels at dose grid closest below the final TDtargetDuringTrial estimates
+##' @slot FinalTDtargetEndOfTrialAtDoseGrid vector of  the dose levels at dose grid closest below the final TDtargetEndOfTrial estimates
+##' @slot FinalTDEOTCIs is the list of all 95\% credibility interval of the final estimates of the TDtargetEndOfTrial 
+##' @slot FinalTDEOTRatios is the vector of the ratios of the CI, the raatio of the upper to the lower 95\% credibility intervals 
+##' of the final estimates of the TDtargetEndOfTrial
+##' @slot FinalCIs list of all the final 95\% credibility intervals of the TDtargetEndofTrial estimates or of the final optimal dose 
+##' estimates when DLE and efficacy responses are incorporated after each simulations
+##' @slot FinalRatios vector of all the final ratios, the ratios of the upper to the lower 95\% credibility interval of the 
+##' final estimates of the TDtargetEndOfTrial or of the final optimal dose estiamtes (when DLE and efficacy responses are
+##' incorporated) after each simulations
 ##' @slot stopReasons todo: add slot description 
 ##' 
 ##' @export
@@ -309,10 +325,26 @@ DualSimulations <- function(rhoEst,
 .PseudoSimulations <-
   setClass(Class="PseudoSimulations",
            representation(fit="list",
+                          FinalTDtargetDuringTrialEstimates="numeric",
+                          FinalTDtargetEndOfTrialEstimates = "numeric",
+                          FinalTDtargetDuringTrialAtDoseGrid="numeric",
+                          FinalTDtargetEndOfTrialAtDoseGrid ="numeric",
+                          FinalTDEOTCIs="list",
+                          FinalTDEOTRatios="numeric",
+                          FinalCIs="list",
+                          FinalRatios="numeric",
                           stopReasons="list"),
            ## note: this prototype is put together with the prototype
            ## for GeneralSimulations
-           prototype(stopReasons=
+           prototype(FinalTDtargetDuringTrialEstimates= c(0.1,0.1),
+                     FinalTDtargetEndOfTrialEstimates=c(0.1,0.1),
+                     FinalTDtargetDuringTrialAtDoseGrid=c(0.1,0.1),
+                     FinalTDtargetEndOfTrialAtDoseGrid=c(0.1,0.1),
+                     FinalTDEOTCIs=list(c(0.1, 0.2),c(0.1, 0.2)),
+                     FinalTDEOTRatios=c(0.1,0.1),
+                     FinalCIs=list(c(0.1, 0.2),c(0.1, 0.2)),
+                     FinalRatios=c(0.1,0.1),
+             stopReasons=
                        list("A", "A")),
            contains="GeneralSimulations",
            validity=
@@ -329,6 +361,14 @@ validObject(.PseudoSimulations())
 
 ##' Initialization function of the 'PseudoSimulations' class
 ##' @param fit please refer to \code{\linkS4class{PseudoSimulations}} class object
+##' @param FinalTDtargetDuringTrialEstimates please refer to \code{\linkS4class{PseudoSimulations}} class object
+##' @param FinalTDtargetEndOfTrialEstimates please refer to \code{\linkS4class{PseudoSimulations}} class object
+##' @param FinalTDtargetDuringTrialAtDoseGrid please refer to \code{\linkS4class{PseudoSimulations}} class object
+##' @param FinalTDtargetEndOfTrialAtDoseGrid please refer to \code{\linkS4class{PseudoSimulations}} class object
+##' @param FinalTDEOTCIs please refer to \code{\linkS4class{PseudoSimulations}} class object
+##' @param FinalTDEOTRatios please refer to \code{\linkS4class{PseudoSimulations}} class object
+##' @param FinalCIs please refer to \code{\linkS4class{PseudoSimulations}} class object
+##' @param FinalRatios please refer to \code{\linkS4class{PseudoSimulations}} class object
 ##' @param stopReasons please refer to \code{\linkS4class{PseudoSimulations}} class object
 ##' @param \dots additional parameters from \code{\linkS4class{GeneralSimulations}}
 ##' @return the \code{\linkS4class{PseudoSimulations}} object
@@ -336,12 +376,28 @@ validObject(.PseudoSimulations())
 ##' @export
 ##' @keywords methods
 PseudoSimulations <- function(fit,
+                              FinalTDtargetDuringTrialEstimates,
+                              FinalTDtargetEndOfTrialEstimates,
+                              FinalTDtargetDuringTrialAtDoseGrid,
+                              FinalTDtargetEndOfTrialAtDoseGrid,
+                              FinalTDEOTCIs,
+                              FinalTDEOTRatios,
+                              FinalCIs,
+                              FinalRatios,
                               stopReasons,
                               ...)
 {
   start <- GeneralSimulations(...)
   .PseudoSimulations(start,
                      fit=fit,
+                     FinalTDtargetDuringTrialEstimates=FinalTDtargetDuringTrialEstimates,
+                     FinalTDtargetEndOfTrialEstimates=FinalTDtargetEndOfTrialEstimates,
+                     FinalTDtargetDuringTrialAtDoseGrid=FinalTDtargetDuringTrialAtDoseGrid,
+                     FinalTDtargetEndOfTrialAtDoseGrid= FinalTDtargetEndOfTrialAtDoseGrid,
+                     FinalTDEOTCIs=FinalTDEOTCIs,
+                     FinalTDEOTRatios=FinalTDEOTRatios,
+                     FinalCIs=FinalCIs,
+                     FinalRatios=FinalRatios,
                      stopReasons=stopReasons)
 }
 
@@ -361,7 +417,16 @@ PseudoSimulations <- function(fit,
 ##' @slot fitEff list of the final values. If DLE and efficacy samples are gerneated, it contains the
 ##' final fitted values. If no DLE and efficacy samples are used, it contains the modal estimates of the
 ##' parameters in the two models and the posterior estimates of the probabilities of the occurrence of a
-##' DLE and the expected efficacy responses. 
+##' DLE and the expected efficacy responses.
+##' @slot FinalGstarEstimates a vector of the final estimates of Gstar at the end of each simulations.
+##' @slot FinalGstarAtDoseGrid is a vectorof the final estimates of Gstar at dose Grid at the end of each simulations
+##' @slot FinalGstarCIs is the list of all 95\% credibility interval of the final estimates of Gstar 
+##' @slot FinalGstarRatios is the vector of the ratios of the CI, the ratio of the upper to the lower 95\% credibility interval
+##' of the final estimates of Gstar
+##' @slot FinalOptimalDose is the vector of the final optimal dose, the minimum of the final TDtargetEndOfTrial estimates and Gstar
+##' estimates
+##' @slot FinalOptimalDoseAtDoseGrid is the vector of the final optimal dose, the minimum of the final TDtargetEndOfTrial estimates 
+##' and Gstar estimates at dose Grid
 ##' @slot sigma2est the vector of the final posterior mean sigma2 estimates
 ##' 
 ##' @export
@@ -369,8 +434,21 @@ PseudoSimulations <- function(fit,
 .PseudoDualSimulations <- 
   setClass(Class="PseudoDualSimulations",
            representation(fitEff="list",
+                          FinalGstarEstimates="numeric",
+                          FinalGstarAtDoseGrid="numeric",
+                          FinalGstarCIs="list",
+                          FinalGstarRatios="numeric",
+                          FinalOptimalDose="numeric",
+                          FinalOptimalDoseAtDoseGrid="numeric",
                           sigma2est="numeric"),
-           prototype(sigma2est= c(0.001,0.002)),
+           prototype( FinalGstarEstimates=c(0.1,0.1),
+                      FinalGstarAtDoseGrid=c(0.1,0.1),
+                      FinalGstarCIs=list(c(0.1, 0.2),
+                      c(0.1, 0.2)),
+                      FinalGstarRatios=c(0.01,0.01),
+                      FinalOptimalDose=c(0.01,0.01),
+                      FinalOptimalDoseAtDoseGrid=c(0.01,0.01),
+             sigma2est= c(0.001,0.002)),
            contains="PseudoSimulations",
            validity=
              function(object){
@@ -385,16 +463,34 @@ validObject(.PseudoDualSimulations())
 
 ##' Initialization function for 'DualPseudoSimulations' class
 ##' @param fitEff please refer to \code{\linkS4class{PseudoDualSimulations}} class object
+##' @param  FinalGstarEstimates please refer to \code{\linkS4class{PseudoDualSimulations}} class object
+##' @param FinalGstarAtDoseGrid please refer to \code{\linkS4class{PseudoDualSimulations}} class object
+##' @param FinalGstarCIs please refer to \code{\linkS4class{PseudoDualSimulations}} class object
+##' @param FinalGstarRatios please refer to \code{\linkS4class{PseudoDualSimulations}} class object
+##' @param FinalOptimalDose please refer to \code{\linkS4class{PseudoDualSimulations}} class object
+##' @param FinalOptimalDoseAtDoseGrid please refer to \code{\linkS4class{PseudoDualSimulations}} class object
 ##' @param sigma2est please refer to \code{\linkS4class{PseudoDualSimulations}} class object
 ##' @param \dots additional parameters from \code{\linkS4class{PseudoSimulations}}
 ##' @return the \code{\linkS4class{PseudoDualSimulations}} object
 PseudoDualSimulations <- function(fitEff,
+                                  FinalGstarEstimates,
+                                  FinalGstarAtDoseGrid,
+                                  FinalGstarCIs,
+                                  FinalGstarRatios,
+                                  FinalOptimalDose,
+                                  FinalOptimalDoseAtDoseGrid,
                                   sigma2est,
                                   ...)
 { 
   start <- PseudoSimulations(...)
   .PseudoDualSimulations(start,
                          fitEff=fitEff,
+                         FinalGstarEstimates=FinalGstarEstimates,
+                         FinalGstarAtDoseGrid=FinalGstarAtDoseGrid,
+                         FinalGstarCIs=FinalGstarCIs,
+                         FinalGstarRatios=FinalGstarRatios,
+                         FinalOptimalDose=FinalOptimalDose,
+                         FinalOptimalDoseAtDoseGrid=FinalOptimalDoseAtDoseGrid,
                          sigma2est=sigma2est)
 }
 
@@ -454,10 +550,32 @@ PseudoDualFlexiSimulations <- function(sigma2betaWest,
 ##'
 ##' @slot targetEndOfTrial the target probability of DLE wanted at the end of a trial
 ##' @slot targetDoseEndOfTrial the dose level corresponds to the target probability
+##' of DLE wanted at the end of a trial, TDEOT
+##' @slot targetDoseEndOfTrialAtDoseGrid the dose level at dose grid corresponds to the target probability
 ##' of DLE wanted at the end of a trial
 ##' @slot targetDuringTrial the target probability of DLE wanted during a trial
 ##' @slot targetDoseDuringTrial the dose level corresponds to the target probability of DLE
-##' wanted during the trial
+##' wanted during the trial. TDDT
+##' @slot targetDoseDuringTrialAtDoseGrid the dose level at dose grid corresponds to the target probability
+##' of DLE wanted during a trial
+##' @slot TDEOTSummary the six-number table summary, include the lowest, the 25th precentile (lower quatile), 
+##' the 50th percentile (median), the mean, the 27th percentile and the highest values of the 
+##' final dose levels obtained corresponds to the target probability of DLE
+##' want at the end of a trial across all simulations
+##' @slot TDDTSummary the six-number table summary, include the lowest, the 25th precentile (lower quatile), 
+##' the 50th percentile (median), the mean, the 27th percentile and the highest values of the 
+##' final dose levels obtained corresponds to the target probability of DLE
+##' want during a trial across all simulations
+##' @slot FinalDoseRecSummary the six-number table summary, include the lowest, the 25th precentile (lower quatile), 
+##' the 50th percentile (median), the mean, the 27th percentile and the highest values of the 
+##' final optimal doses, which is either the TDEOT when only DLE response are incorporated into 
+##' the escalation procedure or the minimum of the TDEOT and Gstar when DLE and efficacy responses are
+##' incorporated, across all simulations
+##' @slot ratioTDEOTSummary the six-number summary table of the final ratios of the upper to the lower 95\%
+##' credibility intervals of the final TDEOTs across all simulations
+##' @slot FinalRatioSummary the six-number summary table of the final ratios of the upper to the lower 95\%
+##' credibility intervals of the final optimal doses across all simulations
+##' #@slot doseRec the dose level that will be recommend for subsequent study
 ##' @slot nsim number of simulations
 ##' @slot propDLE proportions of DLE in the trials
 ##' @slot meanToxRisk mean toxicity risks for the patients
@@ -485,8 +603,16 @@ PseudoDualFlexiSimulations <- function(sigma2betaWest,
   setClass(Class="PseudoSimulationsSummary",
            representation(targetEndOfTrial="numeric",
                           targetDoseEndOfTrial="numeric",
+                          targetDoseEndOfTrialAtDoseGrid="numeric",
                           targetDuringTrial="numeric",
                           targetDoseDuringTrial="numeric",
+                          targetDoseDuringTrialAtDoseGrid="numeric",
+                          TDEOTSummary="table",
+                          TDDTSummary="table",
+                          FinalDoseRecSummary="table",
+                          ratioTDEOTSummary="table",
+                          FinalRatioSummary="table",
+                          #doseRec="numeric",
                           nsim="integer",
                           propDLE="numeric",
                           meanToxRisk="numeric",
@@ -514,6 +640,10 @@ PseudoDualFlexiSimulations <- function(sigma2betaWest,
 ##' 
 ##' @slot targetGstar the target dose level such that its gain value is at maximum
 ##' @slot targetGstarAtDoseGrid the dose level at dose Grid closest and below Gstar
+##' @slot GstarSummary the six-number table summary (lowest, 25th, 50th (median), 75th percentile, mean 
+##' and highest value) of the final Gstar values obtained across all simulations
+##' @slot ratioGstarSummary the six-number summary table of the ratios of the upper to the lower 95\%
+##' credibility intervals of the final Gstar across all simulations
 ##' @slot EffFitAtDoseMostSelected fitted expected mean efficacy value at dose most often
 ##' selected
 ##' @slot meanEffFit list with mean, lower (2.5%) and upper (97.5%) quantiles of the fitted expected 
@@ -527,5 +657,7 @@ PseudoDualFlexiSimulations <- function(sigma2betaWest,
            representation=
              representation(targetGstar="numeric",
                             targetGstarAtDoseGrid="numeric",
+                            GstarSummary="table",
+                            ratioGstarSummary="table",
                             EffFitAtDoseMostSelected="numeric",
                             meanEffFit="list"))
